<?php
/*
Plugin Name: WP Greet Box
Plugin URI: http://omninoggin.com/projects/wordpress-plugins/wp-greet-box-wordpress-plugin/
Description: Show a different message to your visitor depending on which site they are coming from.  For example, you can ask Digg visitors to Digg your post, Google visitors to subscribe to your RSS feed, and more!  Best of all, this plugin is compatible with various WordPress cache plugins.
Version: 4.0
Author: Thaya Kareeson
Author URI: http://omninoggin.com/
*/

/*
Copyright 2008 Thaya Kareeson (email : thaya.kareeson@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class wpgb {

  static $option_name = 'wp_greet_box';

  function get_default_options() {
    return array(
      'before_greet'     => '<div class="greet_block">',
      'after_greet'      => '</div><div style="clear:both"></div>',
      'before_icon'      => '<div class="greet_image">',
      'after_icon'       => '</div>',
      'before_text'      => '<div class="greet_text">',
      'after_text'       => '</div>',
      'exclude_referrer' => 'friendfeed\\.com|google\\.com/reader',
      'rss_link'         => get_bloginfo('rss_url'),
      'message_default'  => array(
        'disable'          => 0,
        'icon'             => wpgb::get_plugin_url().'/images/'.'rss_icon.png',
        'timeout'          => 14400,
        'text'             => 'Hello there! If you are new here, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.'
      ),
      'message_noscript' => array(
        'disable'          => 0,
        'icon'             => wpgb::get_plugin_url().'/images/'.'rss_icon.png',
        'text'             => 'Hello there! If you are new here, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.'
      ),
      'messages'         => array(
        array(
          'referrer' => 'del.icio.us',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'delicious_icon.png',
          'timeout'  => 0,
          'text'     => 'Hello fellow <strong>del.icio.us</strong> user! Feel free to <a href="http://del.icio.us/post?url=[[escaped-permalink]]" rel="nofollow"><strong>bookmark this page</strong></a> for future reference if you like it!'
        ),
        array(
          'referrer' => 'delicious.com',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'delicious_icon.png',
          'timeout'  => 0,
          'text'     => 'Hello fellow <strong>delicious</strong> user! Feel free to <a href="http://delicious.com/post?url=[[escaped-permalink]]" rel="nofollow"><strong>bookmark this page</strong></a> for future reference if you like it!'
        ),
        array(
          'referrer' => 'digg.com',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'digg_icon.png',
          'timeout'  => 0,
          'text'     => 'Hello fellow <strong>Digger</strong>! If you like this page, don\'t forget to <a href="http://digg.com/submit?url=[[escaped-permalink]]" rel="nofollow"><strong>digg it</strong></a>!'
        ),
        array(
          'referrer' => 'google.com',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'google_icon.png',
          'timeout'  => 1440,
          'text'     => 'Welcome <strong>Googler</strong>! If you find this page useful, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.'
        ),
        array(
          'referrer' => 'stumbleupon.com',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'stumbleupon_icon.png',
          'timeout'  => 0,
          'text'     => 'Hello fellow <strong>Stumbler</strong>! Don\'t forget to <a href="http://www.stumbleupon.com/submit?url=[[escaped-permalink]]" rel="nofollow"><strong>give me a thumbs up</strong></a> if you like this page!'
        ),
        array(
          'referrer' => 'technorati.com',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'technorati_icon.png',
          'timeout'  => 0,
          'text'     => 'Hello fellow <strong>Technorati</strong> user! Don\'t forget to <a href="http://technorati.com/faves?add=[[escaped-permalink]]" rel="nofollow"><strong>favorite this blog</strong></a> if you like it!'
        ),
        array(
          'referrer' => 'twitter.com',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'twitter_icon.png',
          'timeout'  => 0,
          'text'     => 'Hello fellow <strong>Twitter</strong> user! Don\'t forget to <a href="http://twitthis.com/twit?url=[[escaped-permalink]]" rel="nofollow"><strong>Twit this post</strong></a> if you like it, or <a href="http://twitter.com/" rel="nofollow"><strong>follow me</strong></a> on Twitter if you find me interesting.'
        ),
        array(
          'referrer' => 'yahoo.com',
          'disable'  => 0,
          'icon'     => wpgb::get_plugin_url().'/images/'.'rss_icon.png',
          'timeout'  => 1440,
          'text'     => 'Welcome fellow <strong>Yahooligan</strong>! If you find this page useful, you might want to <a href="[[rss-link]]" rel="nofollow"><strong>subscribe to the RSS feed</strong></a> for updates on this topic.'
        )
      )
    );
  }

  function activate() {
    if ( !get_option($wpgb_option) ) {
      // set default options if no options exist
      add_option( wpgb::$option_name, wpgb::get_default_options() );
    }
  }

  function load_admin_scripts() {
    echo(
      '<link rel="stylesheet" href="'.wpgb::get_plugin_url().'/css/wp-greet-box-admin.css" type="text/css"/>'.
      '<script type="text/javascript" src="'.wpgb::get_plugin_url().'/js/jquery.livequery.js"></script>'.
      '<script type="text/javascript" src="'.wpgb::get_plugin_url().'/js/admin_functions.js"></script>'.
      '<script type="text/javascript" src="'.wpgb::get_plugin_url().'/js/admin_onload.js"></script>' 
    );
  }

  function load_scripts() {
    echo(
      '<link rel="stylesheet" href="'.wpgb::get_plugin_url().'/css/wp-greet-box.css" type="text/css"/>'.
      '<script type="text/javascript" src="'.wpgb::get_plugin_url().'/js/functions.js"></script>'.
      '<script type="text/javascript" src="'.wpgb::get_plugin_url().'/js/onload.js"></script>'
    );
  }

  function queue_jquery() {
    wp_enqueue_script('jquery');
  }

  function display_default_row($type, $wrap=True) {
    extract(get_option(wpgb::$option_name));
    if($type == "default"){
      $m = $message_default;
      $type = 'default';
    }
    else{
      $m = $message_noscript;
      $type = 'noscript';
    }
    if($m['disable']){
      $a_action = 'activate';
      $a_class = 'inactive';
      $a_text= 'Activate';
    }
    else{
      $a_action = 'deactivate';
      $a_class = 'active';
      $a_text = 'Deactivate';
    }
    if($wrap){
      echo(
      '<div id="wpgb_message_'.$type.'" class="wpgb_admin_'.$a_class.'_message">'.
        '<div id="wpgb_message_row_'.$type.'" class="wpgb_admin_message_row">'
      );
    }
    echo(
          '<div class="wpgb_admin_column_referrer"><strong>'.strtoupper($type).'&nbsp;</strong></div>'.
          '<div class="wpgb_admin_column_icon"><img src="'.$m['icon'].'"/>&nbsp;</div>'.
          '<div class="wpgb_admin_column_message">'.$m['text'].'&nbsp;</div>'.
          '<div class="wpgb_admin_column_action">'.
            '<a href="#" class="wpgb_admin_action" entry="'.$type.'" action="edit">Edit</a> | '.
            '<a href="#" class="wpgb_admin_action" entry="'.$type.'" action="'.$a_action.'">'.$a_text.'</a>'.
          '</div>'.
          '<div id="wpgb_message_view_loading_'.$type.'" class="wpgb_admin_loading"><img src="'.wpgb::get_plugin_url().'/images/loading.gif"/></div>'.
          '<div class="clear"></div>'
    );
    if($wrap){
      echo(
        '</div>'.
        '<div id="wpgb_message_view_'.$type.'" class="wpgb_admin_message_view" style="display:none"></div>'.
        '<div class="clear"></div>'.
      '</div>'
      );
    }
  }

  function display_message_row($id, $wrap=True) {
    extract(get_option(wpgb::$option_name));
    if($messages[$id]['disable']){
      $a_action = 'activate';
      $a_class = 'inactive';
      $a_text= 'Activate';
    }
    else{
      $a_action = 'deactivate';
      $a_class = 'active';
      $a_text = 'Deactivate';
    }
    if($wrap){
      echo(
      '<div id="wpgb_message_'.$id.'" class="wpgb_admin_'.$a_class.'_message">'.
        '<div id="wpgb_message_row_'.$id.'" class="wpgb_admin_message_row">'
      );
    }
    echo(
          '<div class="wpgb_admin_column_referrer">'.$messages[$id]['referrer'].'&nbsp;</div>'.
          '<div class="wpgb_admin_column_icon"><img src="'.$messages[$id]['icon'].'"/>&nbsp;</div>'.
          '<div class="wpgb_admin_column_message">'.$messages[$id]['text'].'&nbsp;</div>'.
          '<div class="wpgb_admin_column_action">'.
            '<a href="#" class="wpgb_admin_action" entry="'.$id.'" action="edit">Edit</a> | '.
            '<a href="#" class="wpgb_admin_action confirm" prompt="Are you sure you want to delete?" entry="'.$id.'" action="delete">Delete</a> | '.
            '<a href="#" class="wpgb_admin_action" entry="'.$id.'" action="'.$a_action.'">'.$a_text.'</a>'.
          '</div>'.
          '<div id="wpgb_message_view_loading_'.$id.'" class="wpgb_admin_loading"><img src="'.wpgb::get_plugin_url().'/images/loading.gif"/></div>'.
          '<div class="clear"></div>'
    );
    if($wrap){
      echo(
        '</div>'.
        '<div id="wpgb_message_view_'.$id.'" class="wpgb_admin_message_view" style="display:none"></div>'.
        '<div class="clear"></div>'.
      '</div>'
      );
    }
  }

  function admin_ajax_update_custom($id, $wpgb_message) {
    // convert "on" to 1 and "off" to 0 for checkbox fields
    // and set defaults for fields that are left blank
    if ( $wpgb_message['disable'] == 'off' )
      $wpgb_message['disable'] = 0;
    elseif ( $wpgb_message['disable'] == 'on' )
      $wpgb_message['disable'] = 1;
    if ( !$wpgb_message['timeout'] )
      $wpgb_message['timeout'] = 0;

    // Update options
    $wpgb_options = get_option(wpgb::$option_name);
    $wpgb_options['messages'][$id] = $wpgb_message;
    update_option(wpgb::$option_name, $wpgb_options );
  }

  function admin_ajax_update_default($type, $wpgb_message) {
    // convert "on" to 1 and "off" to 0 for checkbox fields
    // and set defaults for fields that are left blank
    if ( $wpgb_message['disable'] == 'off' )
      $wpgb_message['disable'] = 0;
    elseif ( $wpgb_message['disable'] == 'on' )
      $wpgb_message['disable'] = 1;
    if ( !$wpgb_message['timeout'] )
      $wpgb_message['timeout'] = 0;

    // Update options
    $wpgb_options = get_option(wpgb::$option_name);
    $wpgb_options['message_'.$type] = $wpgb_message;
    update_option(wpgb::$option_name, $wpgb_options );
  }

  function update_options_general() {
    $wpgb_options_general = stripslashes_deep($_POST['wpgb_options_general']);

    // set defaults if some fields that are left blank
    if ( !$wpgb_options_general['rss_link'] )
      $wpgb_options_general['rss_link'] = get_bloginfo('rss_url');

    // Update options
    $wpgb_options = get_option(wpgb::$option_name);
    foreach($wpgb_options_general as $key => $value) {
      $wpgb_options[$key] = $value;
    }
    update_option(wpgb::$option_name, $wpgb_options);
  }

  function admin_ajax_add($wpgb_message) {
    // convert "on" to 1 and "off" to 0 for checkbox fields
    // and set defaults for fields that are left blank
    if ( $wpgb_message['disable'] == 'off' )
      $wpgb_message['disable'] = 0;
    elseif ( $wpgb_message['disable'] == 'on' )
      $wpgb_message['disable'] = 1;
    if ( !$wpgb_message['timeout'] )
      $wpgb_message['timeout'] = 0;

    // Add to options
    $wpgb_options = get_option(wpgb::$option_name);
    $wpgb_options['messages'][] = $wpgb_message;
    update_option(wpgb::$option_name, $wpgb_options );
    return sizeof($wpgb_options['messages']) - 1;
  }

  function admin_ajax_delete($id) {
    $wpgb_options = get_option(wpgb::$option_name);
    // delete item but can't reindex yet
    unset($wpgb_options['messages'][$id]);

    // Update options
    update_option(wpgb::$option_name, $wpgb_options );
    return sizeof($wpgb_options['messages']) - 1;
  }

  function reset_options() {
    if ( !get_option(wpgb::$option_name) ) {
      add_option(wpgb::$option_name, wpgb::get_default_options());
    }
    else {
      update_option(wpgb::$option_name, wpgb::get_default_options());
    }
  }

  function get_plugin_dir() {
    // Pre-2.6 compatibility
    if ( !defined('WP_CONTENT_DIR') )
      define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );
    return WP_CONTENT_DIR.'/plugins/'.plugin_basename(dirname(__FILE__));
  }

  function get_plugin_url() {
    // Pre-2.6 compatibility
    if ( !defined('WP_CONTENT_URL') )
      define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
    return WP_CONTENT_URL.'/plugins/'.plugin_basename(dirname(__FILE__));
  }

  function get_current_page_url() {
    $isHTTPS = (isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"] == "on");
    $port = (isset($_SERVER["SERVER_PORT"]) && ((!$isHTTPS && $_SERVER["SERVER_PORT"] != "80") || ($isHTTPS && $_SERVER["SERVER_PORT"] != "443")));
    $port = ($port) ? ':'.$_SERVER["SERVER_PORT"] : '';
    $url = ($isHTTPS ? 'https://' : 'http://').$_SERVER["SERVER_NAME"].$port.$_SERVER["REQUEST_URI"];
    return $url;
  }

  function get_icon_html($icon_file) {
    return '<img src="'.$icon_file.'"/>';
  }

  function get_greet_html($icon_file, $text, $closable = true) {
    extract(get_option(wpgb::$option_name));
    $greet_html  = ''.$before_greet.$before_text;
    if ( strlen ( $icon_file ) > 0 ) {
      // do not show icon if there is no icon url
      $greet_html .= $before_icon.wpgb::get_icon_html($icon_file).$after_icon;
    }
    $greet_html .= $text.$after_text;
    if($closable) {
      $greet_html .= '<div class="greet_block_close"><a id="greet_block_close">X</a></div>';
    }
    $greet_html .= $after_greet.'';
    $greet_html  = str_replace('[[rss-link]]', $rss_link, $greet_html);
    $greet_html  = str_replace('[[escaped-permalink]]', rawurlencode(wpgb::get_current_page_url()), $greet_html);
    return $greet_html;
  }

  function generate_greet_xml($message) {
    $content  = "<message>\n";
    $content .= "  <text>".htmlspecialchars(wpgb::get_greet_html($message['icon'], $message['text']))."</text>\n";
    $content .= "</message>\n";

    return $content;
  }

  function find_greet_xml($referrer, $visit_delta) {
    extract(get_option(wpgb::$option_name));

    if(!isset($exclude_referrer) || !strlen($exclude_referrer) || !preg_match($exclude_referrer, $referrer)) {
      // if not one of the excluded URLs
      foreach ( $messages as $message ) {
        if(stristr($referrer, $message['referrer']) && strlen($message['text']) > 0 && !$message['disable']) {
          if($visit_delta < 0 || $visit_delta >= $message['timeout']) {
            return wpgb::generate_greet_xml($message);
          }
        }
      }

      if($referrer == 'default' && strlen($message_default['text']) > 0 && !$message_default['disabled']) {
        // if no custom greeting messages found, display default if not disabled
        if($visit_delta < 0 || $visit_delta >= $message_default['timeout']) {
          return wpgb::generate_greet_xml($message_default);
        }
      }
    }
    else {
      // if it is an excluded referrer then return nothing
      return "";
    }
  }

  function display_wp_greet_box() {
    // echo '<script type="text/javascript" src="'.wpgb::get_plugin_url().'/js/wp-greet-box.js"></script>';
    echo '<div id="greet_block">';
    extract(get_option(wpgb::$option_name));
    if(!$message_noscript['disable']) {
      echo '<noscript>';
      echo wpgb::get_greet_html($message_noscript['icon'], $message_noscript['text'], false);
      echo '</noscript>';
    }
    echo '</div>';
  }

  function admin_request_handler() {
    if(isset($_POST['wpgb_action'])){
      if(isset($_POST['wpgb_id'])){
        if ( strtolower($_POST['wpgb_action']) == 'activate' ) {
          wpgb::admin_ajax_activate($_POST['wpgb_id']);
        }
        elseif ( strtolower($_POST['wpgb_action']) == 'deactivate' ) {
          wpgb::admin_ajax_deactivate($_POST['wpgb_id']);
        }
        elseif ( strtolower($_POST['wpgb_action']) == 'delete' ) {
          wpgb::admin_ajax_delete($_POST['wpgb_id']);
        }
        elseif ( strtolower($_POST['wpgb_action']) == 'edit' ) {
          if(is_numeric($_POST['wpgb_id'])){
            wpgb::admin_ajax_edit($_POST['wpgb_id']);
          }
          else{
            wpgb::admin_ajax_edit_default($_POST['wpgb_id']);
          }
        }
        elseif ( strtolower($_POST['wpgb_action']) == 'update' ) {
          if(is_numeric($_POST['wpgb_id'])){
            wpgb::admin_ajax_update_custom($_POST['wpgb_id'], stripslashes_deep($_POST['wpgb_message']));
            wpgb::display_message_row($_POST['wpgb_id'], False);
          }
          else{
            wpgb::admin_ajax_update_default($_POST['wpgb_id'], stripslashes_deep($_POST['wpgb_message']));
            wpgb::display_default_row($_POST['wpgb_id'], False);
          }
        }
        else {
          echo 'Invalid wpgb_action.';
        }
      }
      else{
        if ( strtolower($_POST['wpgb_action']) == 'add' ) {
          $id = wpgb::admin_ajax_add(stripslashes_deep($_POST['wpgb_message']));
          wpgb::display_message_row($id);
        }
        else {
          echo 'Invalid wpgb_action.';
        }
      }
      exit();
    }
  }

  function admin_ajax_activate($id) {
    $wpgb_options = get_option(wpgb::$option_name);
    if($id == 'default'){
      $wpgb_options['message_default']['disable'] = 0;
    }
    elseif($id == 'noscript'){
      $wpgb_options['message_noscript']['disable'] = 0;
    }
    else{
      $wpgb_options['messages'][$id]['disable'] = 0;
    }
    update_option(wpgb::$option_name, $wpgb_options );
  }

  function admin_ajax_deactivate($id) {
    $wpgb_options = get_option(wpgb::$option_name);
    if($id == 'default'){
      $wpgb_options['message_default']['disable'] = 1;
    }
    elseif($id == 'noscript'){
      $wpgb_options['message_noscript']['disable'] = 1;
    }
    else{
      $wpgb_options['messages'][$id]['disable'] = 1;
    }
    update_option(wpgb::$option_name, $wpgb_options );
  }

  function admin_ajax_edit($id) {
    extract(get_option(wpgb::$option_name));

    if ( $messages[$id]['disable'] )
      $checkmark = 'checked';
    else
      $checkmark = '';

    echo(
      '<form id="wpgb_custom_message_form_'.$id.'" action="index.php" method="post">'.
        'Referrer URL:<br/>'.
        '<input name="wpgb_message[referrer]" type="text" class="wpgb_focusable" value="'.attribute_escape($messages[$id]['referrer']).'"/><br/><br/>'.
        'Visitor Timeout (minutes):<br/>'.
        '<input name="wpgb_message[timeout]" type="text" class="wpgb_focusable" value="'.attribute_escape($messages[$id]['timeout']).'"/><br/><br/>'.
        'Greeting Icon (optional):'.
        '<input name="wpgb_message[icon]" type="text" class="wpgb_focusable widefat" value="'.attribute_escape($messages[$id]['icon']).'"/><br/><br/>'.
        'Greeting message:'.
        '<textarea name="wpgb_message[text]" class="wpgb_focusable widefat" rows="4">'.attribute_escape($messages[$id]['text']).'</textarea><br/><br/>'.
        // '<input name="wpgb_message[disable]" type="checkbox" '.$checkmark.'"/> Disable this message<br/>'.
        '<p class="submit">'.
          '<input type="submit" class="wpgb_admin_submit" entry="'.$id.'" value="Save" />'.
          '<input type="button" class="wpgb_admin_cancel" entry="'.$id.'" value="Cancel"/>'.
        '</p>'.
        '<input type="hidden" name="wpgb_id" value="'.$id.'"/>'.
        '<input type="hidden" name="wpgb_action" value="update"/>'.
      '</form>'
    );
  }

  function admin_ajax_edit_default($type) {
    extract(get_option(wpgb::$option_name));

    if($type == "default"){
      $m = $message_default;
      $type = 'default';
    }
    else{
      $m = $message_noscript;
      $type = 'noscript';
    }

    if ( $m['disable'] )
      $checkmark = 'checked';
    else
      $checkmark = '';

    echo(
      '<form id="wpgb_custom_message_form_'.$type.'" action="index.php" method="post">'.
        'Visitor Timeout (minutes):<br/>'.
        '<input name="wpgb_message[timeout]" type="text" class="wpgb_focusable" value="'.attribute_escape($m['timeout']).'"/><br/><br/>'.
        'Greeting Icon (optional):'.
        '<input name="wpgb_message[icon]" type="text" class="wpgb_focusable widefat" value="'.attribute_escape($m['icon']).'"/><br/><br/>'.
        'Greeting message:'.
        '<textarea name="wpgb_message[text]" class="wpgb_focusable widefat" rows="4">'.attribute_escape($m['text']).'</textarea><br/><br/>'.
        '<p class="submit">'.
          '<input type="submit" class="wpgb_admin_submit" entry="'.$type.'" value="Save" />'.
          '<input type="button" class="wpgb_admin_cancel" entry="'.$type.'" value="Cancel"/>'.
        '</p>'.
        '<input type="hidden" name="wpgb_id" value="'.$type.'"/>'.
        '<input type="hidden" name="wpgb_action" value="update"/>'.
      '</form>'
    );
  }

  function admin_menu() {
    $options_page = add_options_page('WP Greet Box', 'WP Greet Box', 'manage_options', 'wp-greet-box', array('wpgb', 'admin_page'));
    add_action('admin_head-'.$options_page, array('wpgb', 'load_admin_scripts'));
  }

  function admin_page() {
    if ( isset($_POST['wpgb_options_general_submit']) ) {
      // if user submits information
      check_admin_referer('wpgb');
      wpgb::update_options_general();
      echo '<div class="updated fade"><p>WP Greet Box options updated.</p></div>';
    }
    elseif ( isset($_POST['wpgb_options_reset']) ) {
      // if user wants to reset all options
      check_admin_referer('wpgb');
      wpgb::reset_options();
      echo '<div class="updated fade"><p>WP Greet Box options has been reset.</p></div>';
    }

    $wpgb_options = get_option(wpgb::$option_name);
    // reindex here when we get the chance to reload page
    $wpgb_options['messages'] = array_values($wpgb_options['messages']);
    // Update options
    update_option(wpgb::$option_name, $wpgb_options );

    extract(get_option(wpgb::$option_name));
?>
      <div class="wrap">
        <h2>WP Greet Box Options</h2>
        <div>
          <a href="<?php echo preg_replace('/&wpgb-page=[^&]*/', '', $_SERVER['REQUEST_URI']); ?>">Greeting Messages</a>&nbsp;|&nbsp;
          <a href="<?php echo preg_replace('/&wpgb-page=[^&]*/', '', $_SERVER['REQUEST_URI']) . '&wpgb-page=general'; ?>">General Configurations</a>&nbsp;|&nbsp;
          <a href="<?php echo preg_replace('/&wpgb-page=[^&]*/', '', $_SERVER['REQUEST_URI']) . '&wpgb-page=documentation'; ?>">Documentation</a>
        </div>
        <?php
          if(isset($_GET['wpgb-page'])) {
            if($_GET['wpgb-page'] == 'documentation') {
              require_once('wp-greet-box-options-documentation.php');
            }
            elseif($_GET['wpgb-page'] == 'general') {
              require_once('wp-greet-box-options-general.php');
            }
          }
          else {
            require_once('wp-greet-box-options-custom.php');
          }
        ?>
      </div>
<?php
  } // function admin_page()
} // class wp_greet_box

function wp_greet_box() {
  wpgb::display_wp_greet_box();
}

if ( function_exists('add_action') ) {
  add_action('admin_menu', array('wpgb', 'admin_menu'));
  add_action('init', array('wpgb', 'admin_request_handler'));
  add_action('wp_head', array('wpgb', 'load_scripts'));
  add_action('wp_print_scripts', array('wpgb', 'queue_jquery'));
}

if ( function_exists('register_activation_hook') ) {
  register_activation_hook(__FILE__, array('wpgb', 'activate'));
}

if (!defined( 'ABSPATH' )) {
  // require scripts needed for running WP Greet Box calls directly
  $root = dirname(dirname(dirname(dirname(__FILE__))));
  if (file_exists($root.DIRECTORY_SEPARATOR.'wp-load.php')) {
    // WP 2.6
    require_once($root.DIRECTORY_SEPARATOR.'wp-load.php');
  } else {
    // Before 2.6
    require_once($root.DIRECTORY_SEPARATOR.'wp-config.php');
  }

  require_once( $root.DIRECTORY_SEPARATOR.'wp-includes'.DIRECTORY_SEPARATOR.'wp-db.php' );

  if ( defined( 'ABSPATH' ) ) {
    // Returning XML
    if(isset($_GET['data']) && $_GET['data'] && isset($_GET['referrer']) && $_GET['referrer'] && isset($_GET['visit_delta']) && $_GET['visit_delta']) {
      if(strtolower($_GET['data']) == 'xml') {
        echo wpgb::find_greet_xml($_GET['referrer'],$_GET['visit_delta']);
        exit;
      }
    }
  }
}

?>
